@@ -38,62 +38,63 @@ def expand(new_array,
                                                  tiling in various dimension.
 
         Examples:
-            >>> numpy.arange(6).reshape(2,3)
+            >>> a = numpy.arange(6, dtype=numpy.uint64).reshape(2,3)
+            >>> a
             array([[0, 1, 2],
-                   [3, 4, 5]])
+                   [3, 4, 5]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape(2,3))
+            >>> expand(a)
             array([[0, 1, 2],
-                   [3, 4, 5]])
+                   [3, 4, 5]], dtype=uint64)
 
-            >>> a = numpy.arange(6).reshape(2,3); a is expand(a)
+            >>> a is expand(a)
             False
 
-            >>> expand(numpy.arange(6).reshape(2,3), 1)
+            >>> expand(a, 1)
             array([[[0],
                     [1],
                     [2]],
             <BLANKLINE>
                    [[3],
                     [4],
-                    [5]]])
+                    [5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape(2,3), (1,))
+            >>> expand(a, (1,))
             array([[[0],
                     [1],
                     [2]],
             <BLANKLINE>
                    [[3],
                     [4],
-                    [5]]])
+                    [5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_after=1)
+            >>> expand(a, shape_after=1)
             array([[[0],
                     [1],
                     [2]],
             <BLANKLINE>
                    [[3],
                     [4],
-                    [5]]])
+                    [5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_after=(1,))
+            >>> expand(a, shape_after=(1,))
             array([[[0],
                     [1],
                     [2]],
             <BLANKLINE>
                    [[3],
                     [4],
-                    [5]]])
+                    [5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_before=1)
+            >>> expand(a, shape_before=1)
             array([[[0, 1, 2],
-                    [3, 4, 5]]])
+                    [3, 4, 5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_before=(1,))
+            >>> expand(a, shape_before=(1,))
             array([[[0, 1, 2],
-                    [3, 4, 5]]])
+                    [3, 4, 5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_before=(3,))
+            >>> expand(a, shape_before=(3,))
             array([[[0, 1, 2],
                     [3, 4, 5]],
             <BLANKLINE>
@@ -101,19 +102,19 @@ def expand(new_array,
                     [3, 4, 5]],
             <BLANKLINE>
                    [[0, 1, 2],
-                    [3, 4, 5]]])
+                    [3, 4, 5]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_after=(4,))
+            >>> expand(a, shape_after=(4,))
             array([[[0, 0, 0, 0],
                     [1, 1, 1, 1],
                     [2, 2, 2, 2]],
             <BLANKLINE>
                    [[3, 3, 3, 3],
                     [4, 4, 4, 4],
-                    [5, 5, 5, 5]]])
+                    [5, 5, 5, 5]]], dtype=uint64)
 
             >>> expand(
-            ...     numpy.arange(6).reshape((2,3)),
+            ...     a,
             ...     shape_before=(3,),
             ...     shape_after=(4,)
             ... )
@@ -141,9 +142,9 @@ def expand(new_array,
             <BLANKLINE>
                     [[3, 3, 3, 3],
                      [4, 4, 4, 4],
-                     [5, 5, 5, 5]]]])
+                     [5, 5, 5, 5]]]], dtype=uint64)
 
-            >>> expand(numpy.arange(6).reshape((2,3)), shape_after = (4,3))
+            >>> expand(a, shape_after=(4,3))
             array([[[[0, 0, 0],
                      [0, 0, 0],
                      [0, 0, 0],
@@ -173,10 +174,10 @@ def expand(new_array,
                     [[5, 5, 5],
                      [5, 5, 5],
                      [5, 5, 5],
-                     [5, 5, 5]]]])
+                     [5, 5, 5]]]], dtype=uint64)
 
             >>> expand(
-            ...     numpy.arange(6).reshape((2,3)),
+            ...     a,
             ...     shape_before=(4,3),
             ... )
             array([[[[0, 1, 2],
@@ -216,7 +217,7 @@ def expand(new_array,
                      [3, 4, 5]],
             <BLANKLINE>
                     [[0, 1, 2],
-                     [3, 4, 5]]]])
+                     [3, 4, 5]]]], dtype=uint64)
     """
 
     if not isinstance(shape_after, tuple):
@@ -255,69 +256,45 @@ def anumerate(new_array, axis=0, start=0, step=1, dtype=None):
             (numpy.ndarray):                     a view of a numpy arange with
                                                  tiling in various dimension.
         Examples:
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64)
-            ... )
+            >>> a = numpy.ones((4,5), dtype=numpy.uint64)
+
+            >>> anumerate(a)
             array([[0, 0, 0, 0, 0],
                    [1, 1, 1, 1, 1],
                    [2, 2, 2, 2, 2],
                    [3, 3, 3, 3, 3]], dtype=uint64)
 
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64),
-            ...     axis=0
-            ... )
+            >>> anumerate(a, axis=0)
             array([[0, 0, 0, 0, 0],
                    [1, 1, 1, 1, 1],
                    [2, 2, 2, 2, 2],
                    [3, 3, 3, 3, 3]], dtype=uint64)
 
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64),
-            ...     axis=0,
-            ...     start=1
-            ... )
+            >>> anumerate(a, axis=0, start=1)
             array([[1, 1, 1, 1, 1],
                    [2, 2, 2, 2, 2],
                    [3, 3, 3, 3, 3],
                    [4, 4, 4, 4, 4]], dtype=uint64)
 
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64),
-            ...     axis=0,
-            ...     start=1,
-            ...     step=2
-            ... )
+            >>> anumerate(a, axis=0, start=1, step=2)
             array([[1, 1, 1, 1, 1],
                    [3, 3, 3, 3, 3],
                    [5, 5, 5, 5, 5],
                    [7, 7, 7, 7, 7]], dtype=uint64)
 
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64),
-            ...     axis=1
-            ... )
+            >>> anumerate(a, axis=1)
             array([[0, 1, 2, 3, 4],
                    [0, 1, 2, 3, 4],
                    [0, 1, 2, 3, 4],
                    [0, 1, 2, 3, 4]], dtype=uint64)
 
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64),
-            ...     axis=1,
-            ...     start=1
-            ... )
+            >>> anumerate(a, axis=1, start=1)
             array([[1, 2, 3, 4, 5],
                    [1, 2, 3, 4, 5],
                    [1, 2, 3, 4, 5],
                    [1, 2, 3, 4, 5]], dtype=uint64)
 
-            >>> anumerate(
-            ...     numpy.ones((4,5), dtype=numpy.uint64),
-            ...     axis=1,
-            ...     start=1,
-            ...     step=2
-            ... )
+            >>> anumerate(a, axis=1, start=1, step=2)
             array([[1, 3, 5, 7, 9],
                    [1, 3, 5, 7, 9],
                    [1, 3, 5, 7, 9],
@@ -369,11 +346,14 @@ def indices(shape, dtype=None):
 
         Examples:
 
-            >>> indices((2, 3))  # doctest: +NORMALIZE_WHITESPACE
+            >>> indices(
+            ...     (2, 3),
+            ...     dtype=numpy.uint64
+            ... )  # doctest: +NORMALIZE_WHITESPACE
             (array([[0, 0, 0],
-                    [1, 1, 1]]),
+                    [1, 1, 1]], dtype=uint64),
              array([[0, 1, 2],
-                    [0, 1, 2]]))
+                    [0, 1, 2]], dtype=uint64))
     """
 
     try:
@@ -381,8 +361,7 @@ def indices(shape, dtype=None):
     except NameError:
         xrange = range
 
-    if dtype is None:
-        dtype = int
+    dtype = dtype if dtype is not None else int
     dtype = numpy.dtype(dtype)
 
     grid = []
@@ -415,17 +394,20 @@ def product(arrays):
                                                                 each array.
 
         Examples:
-            >>> product([numpy.arange(2), numpy.arange(3)])
+            >>> product([
+            ...     numpy.arange(2, dtype=numpy.uint64),
+            ...     numpy.arange(3, dtype=numpy.uint64)
+            ... ])
             array([[0, 0],
                    [0, 1],
                    [0, 2],
                    [1, 0],
                    [1, 1],
-                   [1, 2]])
+                   [1, 2]], dtype=uint64)
 
             >>> product([
             ...     numpy.arange(2, dtype=float),
-            ...     numpy.arange(3)
+            ...     numpy.arange(3, dtype=numpy.uint64)
             ... ])
             array([[ 0.,  0.],
                    [ 0.,  1.],
@@ -435,9 +417,9 @@ def product(arrays):
                    [ 1.,  2.]])
 
             >>> product([
-            ...     numpy.arange(2),
-            ...     numpy.arange(3),
-            ...     numpy.arange(4)
+            ...     numpy.arange(2, dtype=numpy.uint64),
+            ...     numpy.arange(3, dtype=numpy.uint64),
+            ...     numpy.arange(4, dtype=numpy.uint64)
             ... ])
             array([[0, 0, 0],
                    [0, 0, 1],
@@ -462,9 +444,9 @@ def product(arrays):
                    [1, 2, 0],
                    [1, 2, 1],
                    [1, 2, 2],
-                   [1, 2, 3]])
+                   [1, 2, 3]], dtype=uint64)
 
-            >>> product(numpy.diag((1, 2, 3)))
+            >>> product(numpy.diag((1, 2, 3)).astype(numpy.uint64))
             array([[1, 0, 0],
                    [1, 0, 0],
                    [1, 0, 3],
@@ -491,7 +473,7 @@ def product(arrays):
                    [0, 2, 3],
                    [0, 0, 0],
                    [0, 0, 0],
-                   [0, 0, 3]])
+                   [0, 0, 3]], dtype=uint64)
     """
 
     try:
@@ -548,14 +530,14 @@ def permute_op(op, array_1, array_2):
                                                  end.
         Examples:
             >>> import operator
-            >>> permute_op(
+            >>> tuple(int(s) for s in permute_op(
             ...     operator.add, numpy.ones((1,3)), numpy.eye(2)
-            ... ).shape
+            ... ).shape)
             (1, 3, 2, 2)
 
-            >>> permute_op(
+            >>> tuple(int(s) for s in permute_op(
             ...     operator.add, numpy.ones((2,2)), numpy.eye(2)
-            ... ).shape
+            ... ).shape)
             (2, 2, 2, 2)
 
             >>> permute_op(
